dj-hitcount
===============

.. image:: https://github.com/abhiabhi94/dj-hitcount/actions/workflows/test.yml/badge.svg?branch=main
    :target: https://github.com/abhiabhi94/dj-hitcount/actions
    :alt: Test

.. image:: https://codecov.io/gh/abhiabhi94/dj-hitcount/branch/main/graph/badge.svg?token=JBorE9i0De
  :target: https://codecov.io/gh/abhiabhi94/dj-hitcount
  :alt: Coverage

.. image:: https://badge.fury.io/py/dj-hitcount.svg
    :target: https://pypi.org/project/dj-hitcount/
    :alt: Latest PyPi version

.. image:: https://img.shields.io/pypi/pyversions/dj-hitcount.svg
    :target: https://pypi.python.org/pypi/dj-hitcount/
    :alt: python

.. image:: https://img.shields.io/pypi/djversions/dj-hitcount.svg
    :target: https://pypi.python.org/pypi/dj-hitcount/
    :alt: django

.. image:: https://readthedocs.org/projects/dj-hitcount/badge/?version=latest
    :target: https://dj-hitcount.readthedocs.io/?badge=latest
    :alt: docs

.. image:: https://img.shields.io/github/license/abhiabhi94/dj-hitcount?color=gr
    :target: https://github.com/abhiabhi94/dj-hitcount/blob/main/LICENSE
    :alt: licence


Basic app that allows you to track the number of hits/views for a particular object.

This project was built upon the efforts of `django-hitcount`_. It was made a separate project as the `original one had been stalled`_ for a long time.

.. _`django-hitcount`: https://github.com/thornomad/django-hitcount
.. _`original one had been stalled`: https://github.com/thornomad/django-hitcount/issues/110


Documentation:
--------------

`<http://dj-hitcount.rtfd.org>`_

Source Code:
------------

`<https://github.com/abhiabhi94/dj-hitcount>`_

Issues
------

Use the GitHub `issue tracker`_ for dj-hitcount to submit bugs, issues, and feature requests.

Changelog
---------

`<http://dj-hitcount.readthedocs.org/en/latest/changelog.html>`_

.. _issue tracker: https://github.com/abhiabhi94/dj-hitcount/issues
